Data
====

Widgets and classes for displaying and managing tabular and file data.

TableView
---------

.. automodule:: mytk.tableview
   :members:
   :show-inheritance:

TabularData
-----------

.. automodule:: mytk.tabulardata
   :members:
   :show-inheritance:

FileViewer
----------

.. automodule:: mytk.fileviewer
   :members:
   :show-inheritance:
